<?php
namespace Planejamento\Entities;

class Receserv extends Base\Receserv
{
    /**
     * Atualiza as quantidades da receita padrão
     *
     * @param String $nrorg           Organização
     * @param String $cdprato         Prato
     * @param String $cdfilauxprat    Fila de prato
     * @param String $cdproduto       Produto
     * @param String $qtbrutase       Quantidade Requerida
     * @param String $qtbrutaseunr    Quantidade Bruta
     * @param String $qtcalcnutrse    Quantidade de Cálculo de Nutrientes
     * @param String $qtcomplprodserv Quantidade Complementar
     * @param String $qtprodrecser    Quantidade
     * @param String $qtunidestse     Quantidade líquida do produto na unidade de estoque
     *
     * @throws \Exception
     *
     * @return null
     */
    public static function atualizaQtdeReceitaServico(
         $produtoReceita, $qtbrutase, $qtbrutaseunr,
        $qtcalcnutrse, $qtcomplprodserv, $qtprodrecser, $qtunidestse
    ) {
        try {
            $produtoReceita->setQtbrutase($qtbrutase);
            $produtoReceita->setQtbrutaseunr($qtbrutaseunr);
            $produtoReceita->setQtcalcnutrse($qtcalcnutrse);
            $produtoReceita->setQtcomplprodserv($qtcomplprodserv);
            $produtoReceita->setQtprodrecser($qtprodrecser);
            $produtoReceita->setQtunidestse($qtunidestse);
            $produtoReceita->persist();
        } catch (\Exception $e) {
            throw $e;
        }
    }

    /**
     * Retorna os produtos da receita por serviço
     *
     * @param String $nrorg        Organização
     * @param String $cdprato      Prato
     * @param String $cdfilauxprat Fila de prato
     *
     * @return mixed
     * @throws \Exception
     */
    public static function getProdutosReceitaServico(
        $nrorg, $cdprato, $cdfilauxprat, $servico, $filial
    ) {
        try {
            /** @var Receserv $receitaServico Receita por Serviço */
            $receitaServico = Receserv::getObjectsByWhere(
                "NRORG = ? AND CDPRATO = ? AND CDSERVFILI = ? AND CDFILIAL = ? AND CDFILAUXPRAT = ?",
                array($nrorg, $cdprato, $servico, $filial, $cdfilauxprat)
            );

            return $receitaServico ;
        } catch (\Exception $e) {
            throw $e;
        }
    }

    /**
     * Retorna o produto da receita por serviço
     *
     * @param String $nrorg        Organização
     * @param String $cdprato      Prato
     * @param String $cdfilauxprat Fila de prato
     * @param String $cdproduto    Produto
     *
     * @throws \Exception
     * @return mixed
     */
    public static function getProdutoReceitaServico(
        $nrorg, $cdprato, $cdfilauxprat, $cdproduto, $servico
    ) {
        try {
            /** @var Receserv $receitaServico Receita por Serviço */
            $receitaServico = Receserv::getObjectByWhere(
                'NRORG = ? AND CDPRATO = ? AND CDFILAUXPRAT = ? AND CDPRODUTO = ? AND CDSERVFILI = ?',
                array($nrorg, $cdprato, $cdfilauxprat, $cdproduto, $servico)
            );

            return $receitaServico ;
        } catch (\Exception $e) {
            throw $e;
        }
    }

}